@@ -27,6 +27,12 @@ class Command(BaseCommand):
             nargs='+',
             help='omit applications',
         )
+        parser.add_argument(
+            '--include',
+            type=str,
+            nargs='+',
+            help='include applications',
+        )
         add_bool_arg(
             parser, 'add-help',
             'docstrings should be included to diagram',
@@ -37,18 +43,35 @@ class Command(BaseCommand):
             'models Choices fields should be described',
             'models Choices fields should not be described'
         )
+        parser.add_argument(
+            '--title',
+            type=str,
+            nargs='?',
+            help='provide title',
+        )
+        add_bool_arg(
+            parser, 'add-legend',
+            'include explanation of the symbols used',
+            'do not include explanation of the symbols used'
+        )
 
     def handle(self, *args, **options):
         output = options['file']
         generate_with_help = options['add-help']
         generate_with_choices = options['add-choices']
+        generate_with_legend = options['add-legend']
+        include = options['include']
         omit = options['omit']
+        title = options['title']
 
         models = apps.get_models()
         uml = generate_puml_class_diagram(
             models,
+            title=title,
+            with_legend=generate_with_legend,
             with_help=generate_with_help,
             with_choices=generate_with_choices,
+            include=include,
             omit=omit,
         )
 
