@@ -90,9 +90,9 @@ def model_repr(model, with_help=True, with_choices=True) -> Tuple[str, dict]:
     uml += f'}}\n'
 
     for related in list(filter(lambda x: isinstance(x, ForeignKey), fields)):
-        uml += f'{meta.label} -- {related.foreign_related_fields[0].model._meta.label}\n'
+        uml += f'{meta.label} *-- {related.foreign_related_fields[0].model._meta.label}\n'
     for related in list(filter(lambda x: isinstance(x, ManyToManyField), fields)):
-        uml += f'{meta.label} -- {related.target_field.model._meta.label}\n'
+        uml += f'{meta.label} *--* {related.target_field.model._meta.label}\n'
 
     if with_choices:
         for choice_field_name, choices in model_choices.items():
@@ -103,22 +103,53 @@ def model_repr(model, with_help=True, with_choices=True) -> Tuple[str, dict]:
 
 
 def is_app_member(model, app_name: str):
-    return  str(model._meta.label).startswith(app_name + '.')
+    return str(model._meta.label).startswith(app_name + '.')
+
+
+def legend() -> str:
+    return """
+    class "Explanation of the symbols used" as DESCRIPTION #FFF { 
+    - AutoField (identifiers)
+    ..
+    + Regular field (anything)
+    ..
+    # ForeignKey (ManyToMany)
+    ..
+    ~ ForeignKey (OneToOne, OneToMany)
+    --
+}\n\n
+"""
 
 
 def generate_puml_class_diagram(
         models,
+        title=None,
+        with_legend=False,
         with_help=True,
         with_choices=True,
+        include=None,
         omit=None,
 ) -> str:
     global_choices = dict()
 
     uml = "@startuml\n"
 
+    if title:
+        uml += f"""
+        skinparam titleFontSize 72
+
+        title
+        {title}
+        end title\n
+        """
+    if with_legend:
+        uml += legend()
+
     for model in models:
         if omit and any([is_app_member(model, to_omit) for to_omit in omit]):
             continue
+        if include and all([not is_app_member(model, to_include) for to_include in include]):
+            continue
         model_uml, model_choices = model_repr(model, with_help=with_help, with_choices=with_choices)
         uml += model_uml
         global_choices = {**global_choices, **model_choices}
